Installation
============
LattPy is available on PyPI_:

.. code-block:: console

   $ pip install lattpy

Alternatively, it can be installed via GitHub_:

.. code-block:: console

   $ pip install git+https://github.com/dylanljones/lattpy.git@VERSION

where `VERSION` is a release or tag (e.g. `0.6.4`). The project can also be
cloned/forked and installed via

.. code-block:: console

   $ python setup.py install


.. _PyPi:
   https://pypi.org/project/lattpy/
.. _GitHub:
   https://github.com/dylanljones/lattpy
